/* ======================================================================== *\
!
! *
! * This file is part of MARS, the MAGIC Analysis and Reconstruction
! * Software. It is distributed to you in the hope that it can be a useful
! * and timesaving tool in analysing Data of imaging Cerenkov telescopes.
! * It is distributed WITHOUT ANY WARRANTY.
! *
! * Permission to use, copy, modify and distribute this software and its
! * documentation for any purpose is hereby granted without fee,
! * provided that the above copyright notice appear in all copies and
! * that both that copyright notice and this permission notice appear
! * in supporting documentation. It is provided "as is" without express
! * or implied warranty.
! *
!
!
!   Author(s): Thomas Bretz  07/2001 (tbretz@uni-sw.gwdg.de)
!
!   Copyright: MAGIC Software Development, 2000-2001
!
!
\* ======================================================================== */

//////////////////////////////////////////////////////////////////////////////
//                                                                          //
//                                                                          //
//////////////////////////////////////////////////////////////////////////////
#include "MClone.h"

#include "MLog.h"
#include "MLogManip.h"

#include "MParList.h"

ClassImp(MClone);

// --------------------------------------------------------------------------
//
// Initializes name and title of the object. It is called by all
// constructors.
//
void MClone::Init(const char *name, const char *title)
{
    *fName  = name  ? name  : "MClone";
    *fTitle = title ? title : "Task to clone a parameter container for later usage";

    fClone        = NULL;
    fParContainer = NULL;
}

// --------------------------------------------------------------------------
//
// Constructor.
//
MClone::MClone(const char *par, const char *name, const char *title)
{
    Init(name, title);

    fParContainerName = par;
}

// --------------------------------------------------------------------------
//
// Constructor.
//
MClone::MClone(const MParContainer *par, const char *name, const char *title)
{
    Init(name, title);

    fParContainer = par;
}

// --------------------------------------------------------------------------
//
// Destructor.
//
MClone::~MClone()
{
    Clear();
}

// --------------------------------------------------------------------------
//
// Checks the parameter list for the existance of the parameter container. If
// the name of it was given in the constructor. It checks also for the
// existance of the histogram container in the parameter list if a name was
// given. If it is not available it tried to create a histogram container
// with the same type as the given object name.
//
Bool_t MClone::PreProcess(MParList *pList)
{
    if (!fParContainer)
    {
        fParContainer = (MParContainer*)pList->FindObject(fParContainerName);
        if (!fParContainer)
        {
            *fLog << dbginf << fParContainerName << " not found... aborting." << endl;
            return kFALSE;
        }
    }
    return kTRUE;
}

void MClone::Clear(Option_t *)
{
    if (!fClone)
        return;

    delete fClone;
    fClone = NULL;
}

// --------------------------------------------------------------------------
//
// Fills the data from the parameter conatiner into the histogram container
//
Bool_t MClone::Process()
{
    Clear();

    fClone = fParContainer->Clone();

    return kTRUE;
} 

